--addon name, addon namespace
local _, ans = ...;

-- Remove textures from a frame
local function hideFrameTextures(frame)
    local regions = { frame:GetRegions() };
    for _, region in ipairs(regions) do
        if region:GetObjectType() == "Texture" then
            region:SetTexture(nil)
        end
    end
end

-- Move a frame with a clear all points before
local function moveFrame(frame, point, relativeFrame, relativePoint, ofsx, ofsy)
    frame:ClearAllPoints();
    frame:SetPoint(point, relativeFrame, relativePoint, ofsx, ofsy);
end

-- Use to debug frames on the screen to show there size and position
local function showFrame(f)
    local t = f:CreateTexture("KdoUiShowFrameTexture", "Background");
    t:SetTexture(ans.textures.blizzardWhiteSquare);
    t:SetVertexColor(1, 0, 0, 0.50);
    t:SetAllPoints(f);
end

-- To not have many digits in the number of a color value
local function ceilColor(color)
    return math.ceil(color*100)/100;
end

-- Transform three color numbers into a string for compare
local function colorToString(r, g, b, a)
    if (not a) then a = 1 end;
    return ceilColor(r) ..",".. ceilColor(g) ..",".. ceilColor(b) ..",".. ceilColor(a);
end

-- Util function to not duplicate frames
local function isFrameExist(name)
    local frame = _G[name];
    local result = false;

    if (frame and frame:GetObjectType() == "Frame") then
        result = true;
    end

    return result;
end

-- Return the KdoUiHideFrame
local function getHideFrame()
    local hideFrameName = "KdoUiHideFrame";

    if  (not isFrameExist(hideFrameName)) then
        local kdoUiHideFrame = CreateFrame("Frame", hideFrameName);
        kdoUiHideFrame:Hide();
        ans.kdoUiHideFrame = kdoUiHideFrame;
    end

    return ans.kdoUiHideFrame;
end

-- Create a timer
-- duration default value is 0.75
local function createTimer(func, duration)
    if (duration == nil) then duration = 0.75 end;
    return C_Timer.NewTimer(duration, func);
end

-- Cancel a timer returned by createTimer
local function cancelTimer(timer)
    if (timer) then 
        timer:Cancel();
        timer = nil;
    end
end

ans.getHideFrame = getHideFrame;
ans.hideFrameTextures = hideFrameTextures;
ans.moveFrame = moveFrame;
ans.showFrame = showFrame;
ans.colorToString = colorToString;
ans.isFrameExist = isFrameExist;
ans.createTimer = createTimer;
ans.cancelTimer = cancelTimer;