--addon name, addon namespace
local _, ans = ...;
local kdoUiPanelName = "KdoUiPanel";
local defaultSearchTags = "KDO UI";
local actionBarSettings = {
    "ShowMainMenuBarOnHover",
    "ShowMultiBarBottomLeftOnHover",
    "ShowMultiBarBottomRightOnHover",
    "ShowMultiBarRightOnHover",
    "ShowMultiBarLeftOnHover",
    "ShowMultiBar5OnHover",
    "ShowMultiBar6OnHover",
    "ShowMultiBar7OnHover"
}

local function KdoUiExportStringDialog_Show(text)
    KdoUiExportStringDialog.InputScrollFrame.EditBox.kdoUiText = text;
    KdoUiExportStringDialog.InputScrollFrame.EditBox:SetText(text);
    KdoUiExportStringDialog.InputScrollFrame.EditBox:HighlightText();
    KdoUiExportStringDialog:Show();
end

local function UiLayoutButton_Click()
    KdoUiExportStringDialog_Show(ans.KdoUiLayoutString);
end

local function DetailsProfileButton_Click()
    KdoUiExportStringDialog_Show(ans.DetailsDamageMeterProfile);
end

local function PlaterProfileButton_Click()
    KdoUiExportStringDialog_Show(ans.PlaterNameplatesProfile);
end

local function Settings_load()
    local category, layout = Settings.RegisterVerticalLayoutCategory("|cffed8428KDO|r UI");
    Settings.RegisterAddOnCategory(category);

    local initializer = CreateSettingsButtonInitializer("|cffed8428KDO|r UI Layout", "Copy to clipboard", UiLayoutButton_Click, "Click on the button to copy the ui code to clipboard then import it in edit mode.");
    initializer:AddSearchTags(defaultSearchTags);
    layout:AddInitializer(initializer);

    initializer = CreateSettingsButtonInitializer("Details! Profile", "Copy to clipboard", DetailsProfileButton_Click, "Click on the button to copy the profile code to clipboard then import it in the addon Details! Damage Meter.");
    initializer:AddSearchTags(defaultSearchTags);
    layout:AddInitializer(initializer);

    if (ans.isMyAccount) then
        initializer = CreateSettingsButtonInitializer("Plater Nameplates Profile", "Copy to clipboard", PlaterProfileButton_Click, "Click on the button to copy the profile code to clipboard then import it in the addon Plater Nameplates.");
        initializer:AddSearchTags(defaultSearchTags);
        layout:AddInitializer(initializer);
    end

    initializer = Settings.CreatePanelInitializer("KdoUiTextTemplate", {text = "The addon |cFFFFFFFFLeatrix Plus|r help me to drag the chat to the edge of the screen and move the chat editbox underneath the chat tab."});
    initializer:AddSearchTags(defaultSearchTags);
    layout:AddInitializer(initializer);
    
    -- SUBCATEGORY Settings
    local subcategory, subLayout = Settings.RegisterVerticalLayoutSubcategory(category, "Settings");

    local variable, name, tooltip = "ShowMicroButtonAndBagsBarOnHover", "Hide menu and bags", "Check to show menu and bags on hover.";
    local setting = CreateAndInitFromMixin(ProxySettingMixin, name, variable, KdoUiData, Settings.VarType.Boolean, Settings.Default.True);
    initializer = Settings.CreateCheckBox(subcategory, setting, tooltip);
    initializer:AddSearchTags(defaultSearchTags);

    variable, name, tooltip = "MicroButtonAndBagsBarOnLeft", "Move menu and bags", "Move menu and bags on top of chat and move queue button on minimap.";
    setting = CreateAndInitFromMixin(ProxySettingMixin, name, variable, KdoUiData, Settings.VarType.Boolean, Settings.Default.False);
    initializer = Settings.CreateCheckBox(subcategory, setting, tooltip);
    initializer:AddSearchTags(defaultSearchTags);

    for index, variable in ipairs(actionBarSettings) do
        name, tooltip = "Hide action bar "..index, "Check to show action bar "..index .." on hover.";
        setting = CreateAndInitFromMixin(ProxySettingMixin, name, variable, KdoUiData, Settings.VarType.Boolean, Settings.Default.False);
        initializer = Settings.CreateCheckBox(subcategory, setting, tooltip);
        initializer:AddSearchTags(defaultSearchTags);
    end

    variable, name, tooltip = "ShowStanceBarHover", "Hide stance action bar", "Check to show stance action bar on hover.";
    setting = CreateAndInitFromMixin(ProxySettingMixin, name, variable, KdoUiData, Settings.VarType.Boolean, Settings.Default.False);
    initializer = Settings.CreateCheckBox(subcategory, setting, tooltip);
    initializer:AddSearchTags(defaultSearchTags);

    variable, name, tooltip = "ShowPetActionBarHover", "Hide pet action bar", "Check to show pet action bar on hover.";
    setting = CreateAndInitFromMixin(ProxySettingMixin, name, variable, KdoUiData, Settings.VarType.Boolean, Settings.Default.False);
    initializer = Settings.CreateCheckBox(subcategory, setting, tooltip);
    initializer:AddSearchTags(defaultSearchTags);

    initializer = Settings.CreatePanelInitializer("KdoUiButtonTemplate", {text = "Apply", onClick = ReloadUI});
    initializer:AddSearchTags(defaultSearchTags);
    subLayout:AddInitializer(initializer);
end

ans.Settings_load = Settings_load;